@@ -74,7 +74,7 @@ def _mkdir(path):
         os.makedirs(path)
     return path
 
-def _save(path):
+def _save(path, types='fail'):
     '''
     pull log from device to report folder
     '''
@@ -83,17 +83,25 @@ def _save(path):
         #snapshot & system log
         bridge = _findExetuable('adb')
         if serial:
-            AdbCommand('%s -s %s shell screencap /sdcard/%s' % (bridge ,serial, FAILURE_SNAPSHOT_NAME)).run()
-            AdbCommand('%s -s %s pull /sdcard/%s %s' % (bridge, serial, FAILURE_SNAPSHOT_NAME, path)).run()
+            if types == 'fail':
+                AdbCommand('%s -s %s shell screencap /sdcard/%s' % (bridge ,serial, FAILURE_SNAPSHOT_NAME)).run()
+                AdbCommand('%s -s %s pull /sdcard/%s %s' % (bridge, serial, FAILURE_SNAPSHOT_NAME, path)).run()
             output = AdbCommand('%s -s %s logcat -v time -d' % (bridge, serial)).run()
             with open(join(path, LOG_FILE_NAME), 'w') as o:
                 o.write(output)
+            AdbCommand('%s -s %s pull /data/log/%s %s' % (bridge, serial, 'logcat.log', path)).run()
+            AdbCommand('%s -s %s pull /data/log/%s %s' % (bridge, serial, 'logcat.log.1', path)).run()
+            #AdbCommand('%s -s %s pull /data/log/%s %s' % (bridge, serial, 'logcat.log.2', path)).run()
         else:
-            AdbCommand('%s shell screencap /sdcard/%s' % (bridge, FAILURE_SNAPSHOT_NAME)).run()
-            AdbCommand('%s pull /sdcard/%s %s' % (bridge, FAILURE_SNAPSHOT_NAME, path)).run()
+            if types == 'fail':
+                AdbCommand('%s shell screencap /sdcard/%s' % (bridge, FAILURE_SNAPSHOT_NAME)).run()
+                AdbCommand('%s pull /sdcard/%s %s' % (bridge, FAILURE_SNAPSHOT_NAME, path)).run()
             output = AdbCommand('%s logcat -v time -d ' % bridge).run()
             with open(join(path, LOG_FILE_NAME), 'w') as o:
                 o.write(output)
+            AdbCommand('%s pull /data/log/%s %s' % (bridge, 'logcat.log', path)).run()
+            AdbCommand('%s pull /data/log/%s %s' % (bridge, 'logcat.log.1', path)).run()
+            #AdbCommand('%s pull /data/log/%s %s' % (bridge, 'logcat.log.2', path)).run()       
     except:
         pass
 
@@ -270,6 +278,8 @@ class FileOutputPlugin(nose.plugins.Plugin):
         
         self._report_path = _mkdir(join(join(self.opt.directory, 'report'), str(self.test_start_time).replace(' ', '_')))
         self._all_report_path = _mkdir(join(self._report_path, 'all'))
+        #add 20140925
+        self._pass_report_path = _mkdir(join(self._report_path, 'pass'))
         self._fail_report_path = _mkdir(join(self._report_path, 'fail'))
         self._error_report_path = _mkdir(join(self._report_path, 'error'))
         self._timeout_report_path = _mkdir(join(self._report_path, 'timeout'))
@@ -478,7 +488,22 @@ class FileOutputPlugin(nose.plugins.Plugin):
         class_name = test.id().split('.')[-2]
         method_name = test.id().split('.')[-1]
         case_dir_name = '%s%s%s' % (class_name, '.', method_name)
+        #add 20140925
+        case_start_time = self.conf.case_start_time
+        case_report_dir_name = '%s%s%s' % (case_dir_name, '@', str(case_start_time).replace(' ', '_'))
+        case_report_dir_path = join(self._pass_report_path, case_report_dir_name)
+        try:
+            tmp = join(os.getcwd(), 'tmp')
+            case_report_dir = _mkdir(join(tmp, case_report_dir_name))
+            #last step snapshot
+            _save(case_report_dir, 'pass')
+        except:
+            pass
+        try:
+            shutil.move(case_report_dir, self._pass_report_path)
+        except:
+            pass
 
         self.result_properties.clear()
         self.result_properties.update({'name':case_dir_name, 'result':'pass', 'start_at':str(self.conf.case_start_time), 'end_at': str(datetime.datetime.now())})
-        _writeResultToFile(self.result_file, self.result_properties)
+        _writeResultToFile(self.result_file, self.result_properties)
\ No newline at end of file
